SYMBOL_MAP = {
    "✧": "sparkle",
    "✦": "star_diamond",
    "★": "star_filled",
    "✴": "eight_pointed_star",
    "✶": "six_pointed_star",
    "✺": "daisy_star",
    "❉": "snowflake",
    "❖": "floral_diamond",
    "➤": "arrow_right",
    "▷": "arrow_play",
    "⊕": "circle_plus",
    "⚡": "lightning",
    "✎": "pencil",
    "↓": "arrow_down",
    "↑": "arrow_up",
    "≡": "hamburger_menu",
    "↺": "refresh",
    "∞": "infinity",
    "👉": "finger_point_right",
    "+": "plus",
    "◯": "circle",
    "■": "square",
}
